@@ -1,8 +1,5 @@
 use crate::prices::{Prices, PricesError};
-use ledger_parser::{
-    Amount, Commodity, CommodityPosition, Ledger, LedgerItem, Posting, PostingAmount, Reality,
-    Transaction,
-};
+use crate::{Amount, Commodity, CommodityPosition, Ledger, Posting, Reality, Transaction};
 use rust_decimal::RoundingStrategy;
 
 /// Handle foreign currencies.
@@ -22,24 +19,22 @@ where
     F2: Fn(&str) -> bool,
     F3: Fn(&str) -> bool,
 {
-    for item in &mut ledger.items {
-        if let LedgerItem::Transaction(transaction) = item {
-            handle_foreign_asset_income(
-                transaction,
-                is_income_account,
-                main_commodity,
-                main_commodity_decimal_points,
-                prices,
-            )?;
-            handle_asset_exchange(transaction, is_asset_account);
-            handle_foreign_asset_expenses(
-                transaction,
-                is_expense_account,
-                main_commodity,
-                main_commodity_decimal_points,
-                prices,
-            )?;
-        }
+    for transaction in &mut ledger.transactions {
+        handle_foreign_asset_income(
+            transaction,
+            is_income_account,
+            main_commodity,
+            main_commodity_decimal_points,
+            prices,
+        )?;
+        handle_asset_exchange(transaction, is_asset_account);
+        handle_foreign_asset_expenses(
+            transaction,
+            is_expense_account,
+            main_commodity,
+            main_commodity_decimal_points,
+            prices,
+        )?;
     }
     Ok(())
 }
@@ -62,16 +57,13 @@ where
 
     // look for postings that spends foreign commodities
     for posting in transaction.postings.iter_mut() {
-        if is_income_account(&posting.account)
-            && posting.amount.is_some()
-            && posting.amount.as_ref().unwrap().amount.commodity.name != main_commodity
-        {
-            let foreign_amount = posting.amount.as_ref().unwrap().clone();
+        if is_income_account(&posting.account) && posting.amount.commodity.name != main_commodity {
+            let foreign_amount = posting.amount.clone();
 
             // convert amount to main commodity
             let mut amount_main_commodity = prices.convert(
-                posting.amount.as_ref().unwrap().amount.quantity,
-                &posting.amount.as_ref().unwrap().amount.commodity.name,
+                posting.amount.quantity,
+                &posting.amount.commodity.name,
                 main_commodity,
                 transaction.date,
             )?;
@@ -88,11 +80,7 @@ where
                     position: CommodityPosition::Right,
                 },
             };
-            posting.amount = Some(PostingAmount {
-                amount: main_currency_amount.clone(),
-                lot_price: None,
-                price: None,
-            });
+            posting.amount = main_currency_amount.clone();
 
             // add postings to trading account that will track currency gains and losses
             main_currency_amount.quantity = -main_currency_amount.quantity;
@@ -101,20 +89,14 @@ where
                 account: "Trading:Exchange".to_string(),
                 reality: Reality::Real,
                 status: None,
-                amount: Some(PostingAmount {
-                    amount: main_currency_amount,
-                    lot_price: None,
-                    price: None,
-                }),
-                balance: None,
+                amount: main_currency_amount,
             });
             new_postings.push(Posting {
                 comment: Some("Auto-generated".to_string()),
                 account: "Trading:Exchange".to_string(),
                 reality: Reality::Real,
                 status: None,
-                amount: Some(foreign_amount),
-                balance: None,
+                amount: foreign_amount,
             });
         }
     }
@@ -142,43 +124,15 @@ where
     }
 
     // is this a transaction between different commodities
-    if transaction.postings[0].amount.is_none() {
-        return;
-    }
-    if transaction.postings[1].amount.is_none() {
-        return;
-    }
-    let commodity1_name = &transaction.postings[0]
-        .amount
-        .as_ref()
-        .unwrap()
-        .amount
-        .commodity
-        .name;
-    let commodity2_name = &transaction.postings[1]
-        .amount
-        .as_ref()
-        .unwrap()
-        .amount
-        .commodity
-        .name;
+    let commodity1_name = &transaction.postings[0].amount.commodity.name;
+    let commodity2_name = &transaction.postings[1].amount.commodity.name;
     if commodity1_name == commodity2_name {
         return;
     }
 
     // add postings to trading account that will track currency gains and losses
-    let mut amount1 = transaction.postings[0]
-        .amount
-        .as_ref()
-        .unwrap()
-        .amount
-        .clone();
-    let mut amount2 = transaction.postings[1]
-        .amount
-        .as_ref()
-        .unwrap()
-        .amount
-        .clone();
+    let mut amount1 = transaction.postings[0].amount.clone();
+    let mut amount2 = transaction.postings[1].amount.clone();
 
     amount1.quantity = -amount1.quantity;
     amount2.quantity = -amount2.quantity;
@@ -188,24 +142,14 @@ where
         account: "Trading:Exchange".to_string(),
         reality: Reality::Real,
         status: None,
-        amount: Some(PostingAmount {
-            amount: amount1,
-            lot_price: None,
-            price: None,
-        }),
-        balance: None,
+        amount: amount1,
     });
     transaction.postings.push(Posting {
         comment: Some("Auto-generated".to_string()),
         account: "Trading:Exchange".to_string(),
         reality: Reality::Real,
         status: None,
-        amount: Some(PostingAmount {
-            amount: amount2,
-            lot_price: None,
-            price: None,
-        }),
-        balance: None,
+        amount: amount2,
     });
 }
 
@@ -227,16 +171,13 @@ where
 
     // look for postings that spends foreign commodities
     for posting in transaction.postings.iter_mut() {
-        if is_expense_account(&posting.account)
-            && posting.amount.is_some()
-            && posting.amount.as_ref().unwrap().amount.commodity.name != main_commodity
-        {
-            let foreign_amount = posting.amount.as_ref().unwrap().clone();
+        if is_expense_account(&posting.account) && posting.amount.commodity.name != main_commodity {
+            let foreign_amount = posting.amount.clone();
 
             // convert amount to main commodity
             let mut amount_main_commodity = prices.convert(
-                posting.amount.as_ref().unwrap().amount.quantity,
-                &posting.amount.as_ref().unwrap().amount.commodity.name,
+                posting.amount.quantity,
+                &posting.amount.commodity.name,
                 main_commodity,
                 transaction.date,
             )?;
@@ -253,14 +194,7 @@ where
                     position: CommodityPosition::Right,
                 },
             };
-            posting.amount = Some(
-                PostingAmount {
-                    amount: main_currency_amount.clone(),
-                    lot_price: None,
-                    price: None,
-                }
-                .clone(),
-            );
+            posting.amount = main_currency_amount.clone();
 
             // add postings to trading account that will track currency gains and losses
             main_currency_amount.quantity = -main_currency_amount.quantity;
@@ -269,20 +203,14 @@ where
                 account: "Trading:Exchange".to_string(),
                 reality: Reality::Real,
                 status: None,
-                amount: Some(PostingAmount {
-                    amount: main_currency_amount,
-                    lot_price: None,
-                    price: None,
-                }),
-                balance: None,
+                amount: main_currency_amount,
             });
             new_postings.push(Posting {
                 comment: Some("Auto-generated".to_string()),
                 account: "Trading:Exchange".to_string(),
                 reality: Reality::Real,
                 status: None,
-                amount: Some(foreign_amount),
-                balance: None,
+                amount: foreign_amount,
             });
         }
     }
